#
#   Copyright (C) 2021 Reiko Asakura. All Rights Reserved.
#
#   Vita Development Suite PSP2 CMake Toolchains 0.1.3
#

# This module is shared by multiple languages; use include blocker.
if(__COMPILER_SNC)
  return()
endif()
set(__COMPILER_SNC 1)

macro(__compiler_snc lang)
  set(CMAKE_${lang}_VERBOSE_FLAG "-verbose")

  set(CMAKE_${lang}_COMPILE_OPTIONS_PIC "")
  set(CMAKE_${lang}_COMPILE_OPTIONS_PIE "")
  set(_CMAKE_${lang}_PIE_MAY_BE_SUPPORTED_BY_LINKER NO)
  set(CMAKE_${lang}_LINK_OPTIONS_PIE "")
  set(CMAKE_${lang}_LINK_OPTIONS_NO_PIE "")

  set(CMAKE_${lang}_LINKER_WRAPPER_FLAG "-Wl,")
  set(CMAKE_${lang}_LINKER_WRAPPER_FLAG_SEP ",")

  if(CMAKE_HOST_SYSTEM_PROCESSOR STREQUAL AMD64 OR CMAKE_HOST_SYSTEM_PROCESSOR STREQUAL x86_64)
    string(APPEND CMAKE_${lang}_FLAGS_INIT " -Xhostarch=64")
  endif()

  string(APPEND CMAKE_${lang}_FLAGS_INIT "")
  string(APPEND CMAKE_${lang}_FLAGS_DEBUG_INIT " -Od -g -D_DEBUG")
  string(APPEND CMAKE_${lang}_FLAGS_MINSIZEREL_INIT " -Os -DNDEBUG")
  string(APPEND CMAKE_${lang}_FLAGS_RELEASE_INIT " -O3 -DNDEBUG")
  string(APPEND CMAKE_${lang}_FLAGS_RELWITHDEBINFO_INIT " -O2 -g -DNDEBUG")

  set(CMAKE_${lang}_CREATE_PREPROCESSED_SOURCE "<CMAKE_${lang}_COMPILER> <DEFINES> <INCLUDES> <FLAGS> -E <SOURCE> > <PREPROCESSED_SOURCE>")
  set(CMAKE_${lang}_CREATE_ASSEMBLY_SOURCE "<CMAKE_${lang}_COMPILER> <DEFINES> <INCLUDES> <FLAGS> -S <SOURCE> -o <ASSEMBLY_SOURCE>")

  set(_CMAKE_${lang}_IPO_SUPPORTED_BY_CMAKE NO)
  set(_CMAKE_${lang}_IPO_MAY_BE_SUPPORTED_BY_COMPILER NO)

  set(CMAKE_INCLUDE_SYSTEM_FLAG_${lang} "-J")

  set(CMAKE_SHARED_LIBRARY_CREATE_${lang}_FLAGS "--oformat=prx")

  set(CMAKE_${lang}_OUTPUT_EXTENSION ".o")

  set(CMAKE_${lang}_CREATE_SHARED_LIBRARY
    "<CMAKE_${lang}_COMPILER> <CMAKE_SHARED_LIBRARY_${lang}_FLAGS> <LANGUAGE_COMPILE_FLAGS> <LINK_FLAGS> <CMAKE_SHARED_LIBRARY_CREATE_${lang}_FLAGS> -o <TARGET> -Wl,--prx-stub-output-dir=<TARGET>/.. <OBJECTS> <LINK_LIBRARIES>")

  set(CMAKE_${lang}_CREATE_STATIC_LIBRARY "<CMAKE_AR> crs <TARGET> <LINK_FLAGS> <OBJECTS>")

  set(CMAKE_${lang}_ARCHIVE_CREATE "<CMAKE_AR> qc <TARGET> <LINK_FLAGS> <OBJECTS>")
  set(CMAKE_${lang}_ARCHIVE_APPEND "<CMAKE_AR> q <TARGET> <LINK_FLAGS> <OBJECTS>")
  set(CMAKE_${lang}_ARCHIVE_FINISH "<CMAKE_AR> s <TARGET>")

  set(CMAKE_${lang}_COMPILER_PREDEFINES_COMMAND "${CMAKE_${lang}_COMPILER}")
  if(CMAKE_${lang}_COMPILER_ARG1)
    separate_arguments(_COMPILER_ARGS NATIVE_COMMAND "${CMAKE_${lang}_COMPILER_ARG1}")
    list(APPEND CMAKE_${lang}_COMPILER_PREDEFINES_COMMAND ${_COMPILER_ARGS})
    unset(_COMPILER_ARGS)
  endif()
  list(APPEND CMAKE_${lang}_COMPILER_PREDEFINES_COMMAND "-Xpredefinedmacros" "-c" "${CMAKE_ROOT}/Modules/CMakeCXXCompilerABI.cpp")

  file(TO_CMAKE_PATH $ENV{SCE_PSP2_SDK_DIR} __SCE_PSP2_SDK_DIR)

  list(APPEND _CMAKE_${lang}_IMPLICIT_INCLUDE_DIRECTORIES_INIT
    ${__SCE_PSP2_SDK_DIR}/target/include
    ${__SCE_PSP2_SDK_DIR}/target/include_common
    ${__SCE_PSP2_SDK_DIR}/host_tools/build/include
  )

  unset(__SCE_PSP2_SDK_DIR)

endmacro()
